{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "SelectVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/local/bin/jdk1.8.0_45/bin/java",
                "-jar",
                "/usr/local/bin/GATK3.6/GenomeAnalysisTK.jar",
                "-T",
                "SelectVariants"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "dbmi/gatk-docker:v1"
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/output.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-L",
                        "position": 3
                    },
                    "id": "#select_variants.cwl/interval_list"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#select_variants.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#select_variants.cwl/vcf"
                }
            ],
            "id": "#select_variants.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.vcf.gz"
                    },
                    "id": "#select_variants.cwl/filtered_vcf"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "collect alignment summary metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectAlignmentSummaryMetrics"
            ],
            "arguments": [
                "OUTPUT=",
                {
                    "valueFrom": "$(runtime.outdir)/AlignmentSummaryMetrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "registry.gsc.wustl.edu/genome/picard-2.4.1-r:2"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "INPUT="
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#collect_alignment_summary_metrics.cwl/bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "REFERENCE_SEQUENCE="
                    },
                    "secondaryFiles": [
                        ".fai"
                    ],
                    "id": "#collect_alignment_summary_metrics.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "AlignmentSummaryMetrics.txt"
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/alignment_summary_metrics"
                }
            ],
            "id": "#collect_alignment_summary_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect HS metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectHsMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/HsMetrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "registry.gsc.wustl.edu/genome/picard-2.4.1-r:2"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "BAIT_INTERVALS="
                    },
                    "id": "#collect_hs_metrics.cwl/bait_intervals"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#collect_hs_metrics.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "PER_TARGET_COVERAGE=PerTargetCoverage.txt"
                    },
                    "id": "#collect_hs_metrics.cwl/per_target_coverage"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "R="
                    },
                    "secondaryFiles": [
                        ".fai"
                    ],
                    "id": "#collect_hs_metrics.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "TARGET_INTERVALS="
                    },
                    "id": "#collect_hs_metrics.cwl/target_intervals"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "HsMetrics.txt"
                    },
                    "id": "#collect_hs_metrics.cwl/hs_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "PerTargetCoverage.txt"
                    },
                    "id": "#collect_hs_metrics.cwl/per_target_coverage_metrics"
                }
            ],
            "id": "#collect_hs_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect insert size metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectInsertSizeMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/InsertSizeMetrics.txt"
                },
                "H=",
                {
                    "valueFrom": "$(runtime.outdir)/InsertSizeHistogram.pdf"
                }
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "registry.gsc.wustl.edu/genome/picard-2.4.1-r:2"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#collect_insert_size_metrics.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "InsertSizeMetrics.txt"
                    },
                    "id": "#collect_insert_size_metrics.cwl/insert_size_metrics"
                }
            ],
            "id": "#collect_insert_size_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools flagstat",
            "baseCommand": [
                "/usr/local/bin/samtools",
                "flagstat"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "registry.gsc.wustl.edu/genome/tagged-alignment:1"
                }
            ],
            "stdout": "flagstat.out",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#samtools_flagstat.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#samtools_flagstat.cwl/flagstats",
                    "outputBinding": {
                        "glob": "flagstat.out"
                    }
                }
            ],
            "id": "#samtools_flagstat.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "verify BAM ID",
            "baseCommand": "/usr/local/bin/verifyBamID",
            "arguments": [
                "--out",
                {
                    "valueFrom": "$(runtime.outdir)/VerifyBamId"
                }
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "registry.gsc.wustl.edu/genome/lims-verifybamid:1"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--bam"
                    },
                    "id": "#verify_bam_id.cwl/bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--vcf"
                    },
                    "id": "#verify_bam_id.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "VerifyBamId.depthSM"
                    },
                    "id": "#verify_bam_id.cwl/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "VerifyBamId.selfSM"
                    },
                    "id": "#verify_bam_id.cwl/verify_bam_id_metrics"
                }
            ],
            "id": "#verify_bam_id.cwl"
        },
        {
            "class": "Workflow",
            "label": "Exome QC workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/bait_intervals"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#main/bam"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#main/collect_hs_metrics_per_target_coverage"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/omni_vcf"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai"
                    ],
                    "id": "#main/reference"
                },
                {
                    "type": "File",
                    "id": "#main/target_intervals"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/collect_alignment_summary_metrics/alignment_summary_metrics",
                    "id": "#main/alignment_summary_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/samtools_flagstat/flagstats",
                    "id": "#main/flagstats"
                },
                {
                    "type": "File",
                    "outputSource": "#main/collect_hs_metrics/hs_metrics",
                    "id": "#main/hs_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/collect_insert_size_metrics/insert_size_metrics",
                    "id": "#main/insert_size_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/collect_hs_metrics/per_target_coverage_metrics",
                    "id": "#main/per_target_coverage_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/verify_bam_id/verify_bam_id_depth",
                    "id": "#main/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputSource": "#main/verify_bam_id/verify_bam_id_metrics",
                    "id": "#main/verify_bam_id_metrics"
                }
            ],
            "steps": [
                {
                    "run": "#collect_alignment_summary_metrics.cwl",
                    "in": [
                        {
                            "source": "#main/bam",
                            "id": "#main/collect_alignment_summary_metrics/bam"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/collect_alignment_summary_metrics/reference"
                        }
                    ],
                    "out": [
                        "#main/collect_alignment_summary_metrics/alignment_summary_metrics"
                    ],
                    "id": "#main/collect_alignment_summary_metrics"
                },
                {
                    "run": "#collect_hs_metrics.cwl",
                    "in": [
                        {
                            "source": "#main/bait_intervals",
                            "id": "#main/collect_hs_metrics/bait_intervals"
                        },
                        {
                            "source": "#main/bam",
                            "id": "#main/collect_hs_metrics/bam"
                        },
                        {
                            "source": "#main/collect_hs_metrics_per_target_coverage",
                            "id": "#main/collect_hs_metrics/per_target_coverage"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/collect_hs_metrics/reference"
                        },
                        {
                            "source": "#main/target_intervals",
                            "id": "#main/collect_hs_metrics/target_intervals"
                        }
                    ],
                    "out": [
                        "#main/collect_hs_metrics/hs_metrics",
                        "#main/collect_hs_metrics/per_target_coverage_metrics"
                    ],
                    "id": "#main/collect_hs_metrics"
                },
                {
                    "run": "#collect_insert_size_metrics.cwl",
                    "in": [
                        {
                            "source": "#main/bam",
                            "id": "#main/collect_insert_size_metrics/bam"
                        }
                    ],
                    "out": [
                        "#main/collect_insert_size_metrics/insert_size_metrics"
                    ],
                    "id": "#main/collect_insert_size_metrics"
                },
                {
                    "run": "#samtools_flagstat.cwl",
                    "in": [
                        {
                            "source": "#main/bam",
                            "id": "#main/samtools_flagstat/bam"
                        }
                    ],
                    "out": [
                        "#main/samtools_flagstat/flagstats"
                    ],
                    "id": "#main/samtools_flagstat"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "source": "#main/target_intervals",
                            "id": "#main/select_variants/interval_list"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/select_variants/reference"
                        },
                        {
                            "source": "#main/omni_vcf",
                            "id": "#main/select_variants/vcf"
                        }
                    ],
                    "out": [
                        "#main/select_variants/filtered_vcf"
                    ],
                    "id": "#main/select_variants"
                },
                {
                    "run": "#verify_bam_id.cwl",
                    "in": [
                        {
                            "source": "#main/bam",
                            "id": "#main/verify_bam_id/bam"
                        },
                        {
                            "source": "#main/select_variants/filtered_vcf",
                            "id": "#main/verify_bam_id/vcf"
                        }
                    ],
                    "out": [
                        "#main/verify_bam_id/verify_bam_id_metrics",
                        "#main/verify_bam_id/verify_bam_id_depth"
                    ],
                    "id": "#main/verify_bam_id"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
